#######
History
#######

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

.. :changelog:

2.0.8 (2020-04-15)
==================

- Bugfix: Filter hidden items unless requested.

2.0.7 (2020-04-10)
==================

- Improve: Consistency: Raise on missing key, even when only 1 part specified.

2.0.6 (2020-04-01)
==================

- Internal: DX improvements.

2.0.5 (2020-04-01)
==================

- Internal: DX improvements.

2.0.4 (2020-03-30)
==================

- Internal: DX improvements.

2.0.3 (2020-03-30)
==================

- Internal: DX and Test improvements.

2.0.2 (2020-03-29)
==================

- Internal: DX and Test improvements.

2.0.1 (2020-03-29)
==================

- Internal: DX [Developer Experience] improvements.

2.0.0 (2020-03-29)
==================

- API change: Rename ``use_stringify`` → ``unmutated``.

- License: Release under MIT License.

- DX: Release and CI improvements.

1.0.0 (2020-01-25)
==================

- DX: Release process improvements (no new features).

0.4.0 (2020-01-19)
==================

- First official release (for |dob|_ and |nark|_).

